@@ -44,19 +44,20 @@
   (:desc #?"apt installed @{packages}")
   (:preprocess (flatten packages))
   (:hostattrs (os:required 'os:debianlike))
-  (:check (all-installed-p packages))
   (:apply
-   (with-maybe-update (apt-get :inform "-y" "install" packages))))
+   (with-maybe-update
+       (with-changes-dpkg-status
+         (apt-get :inform "-y" "install" packages)))))
 
 (defprop installed-minimally :posix (&rest packages)
   "Ensure all of the apt packages PACKAGES are installed, without recommends."
   (:desc #?"apt installed @{packages}")
   (:preprocess (flatten packages))
   (:hostattrs (os:required 'os:debianlike))
-  (:check (all-installed-p packages))
   (:apply
    (with-maybe-update
-       (apt-get :inform "-y" "--no-install-recommends" "install" packages))))
+       (with-changes-dpkg-status
+        (apt-get :inform "-y" "--no-install-recommends" "install" packages)))))
 
 (defun install-backports (args packages)
   (with-maybe-update
@@ -93,10 +94,8 @@ each of those dependencies in PACKAGES."
   (:hostattrs
    (declare (ignore packages))
    (os:required 'os:debianlike))
-  (:check
-   (none-installed-p packages))
   (:apply
-   (apt-get :inform "-y" "remove" packages)))
+   (with-changes-dpkg-status (apt-get :inform "-y" "remove" packages))))
 
 (defprop reconfigured :posix (package &rest triples)
   "Where each of TRIPLES is a list of three strings, a debconf template, type
@@ -199,13 +198,11 @@ only upgrade Debian stable."
   (:desc #?"Uses parent's apt mirror(s), if any")
   (aand (get-parent-hostattrs :apt.mirrors) `(mirrors ,@it)))
 
-(defprop proxy :posix (uri)
+(defproplist proxy :posix (uri)
   (:desc #?"${uri} apt proxy selected")
-  (:hostattrs
-   (pushnew-hostattr :apt.proxy uri))
-  (:apply
-   (file:has-content "/etc/apt/apt.conf.d/20proxy"
-                     (format nil "Acquire::HTTP::Proxy \"~A\";~%" uri))))
+  (:hostattrs (pushnew-hostattr :apt.proxy uri))
+  (file:exists-with-content "/etc/apt/apt.conf.d/20proxy"
+    (format nil "Acquire::HTTP::Proxy \"~A\";~%" uri)))
 
 (defproplist uses-parent-proxy :posix ()
   (:desc #?"Uses parent's apt proxy")
@@ -401,6 +398,8 @@ in testing, you could use:
   :test #'string=)
 
 (defun all-installed-p (&rest packages)
+  "Return true if all of PACKAGES, a list of non-virtual packages, are
+installed."
   (loop with n = 0
         with packages* = (flatten packages)
         for line in (apt-cache-policy packages*)
@@ -409,6 +408,8 @@ in testing, you could use:
         finally (return (= n (length packages*)))))
 
 (defun none-installed-p (&rest packages)
+  "Returns true if none of PACKAGES, a list of non-virtual packages, are
+installed."
   (loop for line in (apt-cache-policy (flatten packages))
         never (re:scan apt-cache-policy-installed line)))
 
