@@ -224,7 +224,12 @@ Uses CL-PPCRE:REGEX-REPLACE, which see for the syntax of REPLACE."
 
 (defprop symlinked :posix (&key from to)
   "Ensure FROM is a symlink to TO.  Symbolic links are overwritten; it is an
-error if FROM is another kind of file, except when unapplying."
+error if FROM is another kind of file, except when unapplying.
+
+The link target, TO, is literal: if it is a relative path, then it is not
+relative to the remote home directory, but instead relative to the directory
+that contains FROM.  To create a link with a target under the remote home
+directory, you can use one or more '../', or an absolute path."
   (:desc #?"Symlinked ${from} -> ${to}")
   (:apply
    (unless (and from to)
@@ -426,6 +431,19 @@ uncommented and used to set the value, if it exists."
                               :parse-kv #?/^([^\s=]+)\s?=\s?(.*)/
                               :new-kv (lambda (k v) #?"${k} = ${v}"))))
 
+(defprop contains-conf-unspaced :posix (file &rest pairs)
+  "Where FILE is a config file in which keys and values are separated by \"=\",
+without spaces, there are no sections, and PAIRS is a list of even length of
+alternating keys and values, set each of these keys and values in FILE.
+
+If there are any other lines which set values for the same keys, they will be
+commented out; the first commented or uncommented line for each key will be
+uncommented and used to set the value, if it exists."
+  (:desc (format nil "~A has ~{~A=~A~^, ~}" file pairs))
+  (:apply (simple-conf-update file pairs
+                              :parse-kv #?/^([^\s=]+)=(.*)/
+                              :new-kv (lambda (k v) #?"${k}=${v}"))))
+
 (defprop contains-conf-shell :posix (file &rest pairs)
   "Where FILE is a shell config file, like those in /etc/default, and PAIRS is a
 list of even length of alternating keys and values, set each of these keys and
